==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/core/container/api/gwt/serder/CountGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.container.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class CountGwtSerDer implements GwtSerDer<net.bluemind.core.container.api.Count> {

	public CountGwtSerDer( ) {
	}

	@Override
	public net.bluemind.core.container.api.Count deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.core.container.api.Count ret = new net.bluemind.core.container.api.Count();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.core.container.api.Count ret, JSONObject json) {

		JSONValue totalJSON = json.get("total");
		ret.total =  GwtSerDerUtils.LONG.deserialize(totalJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.core.container.api.Count o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.core.container.api.Count o, JSONObject ret) {

		ret.put("total",  GwtSerDerUtils.LONG.serialize( o.total ));
	}
}

==> net.bluemind.p2.platform-5.4.2696.zip: net/bluemind/core/container/api/gwt/serder/CountGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.container.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class CountGwtSerDer implements GwtSerDer<net.bluemind.core.container.api.Count> {

	public CountGwtSerDer( ) {
	}

	@Override
	public net.bluemind.core.container.api.Count deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.core.container.api.Count ret = new net.bluemind.core.container.api.Count();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.core.container.api.Count ret, JSONObject json) {
		JSONValue totalJSON = json.get("total");
		ret.total =  GwtSerDerUtils.LONG.deserialize(totalJSON);
	}

	public void deserializeTo(net.bluemind.core.container.api.Count ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("total")) {
			JSONValue totalJSON = json.get("total");
			ret.total =  GwtSerDerUtils.LONG.deserialize(totalJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.core.container.api.Count o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.core.container.api.Count o, JSONObject ret) {

		ret.put("total",  GwtSerDerUtils.LONG.serialize( o.total ));
	}

	public void serializeTo(net.bluemind.core.container.api.Count o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("total")) {
			ret.put("total",  GwtSerDerUtils.LONG.serialize( o.total ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
